#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/mdadm-update.sh - paramater update script
#
# Creation   :  2011-10-02 hbfl
# Last update:  $Id: mdadm-update.sh 41043 2016-03-20 15:17:19Z hbfl $
#
# Copyright (c) 2011-2016 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=mdadm

# include configlib
. /var/install/include/configlib

# ---------------------------------------------------------------------------
# set default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_MDADM='no'

    MDADM_DELAY='60'
    MDADM_MAIL="root@$(hostname -d)"
    MDADM_SEND_MAIL_ON_START='no'
    MDADM_SEND_EVENT_TO_SYSLOG='no'
    MDADM_SEND_EVENT_MAIL='no'
    MDADM_SEND_STATUS_MAIL=''
}

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2011-10-02" "hbfl"
    # -----------------------------------------------------------------------

    # -----------------------------------------------------------------------
    printgroup "Basic configuration"
    # -----------------------------------------------------------------------

    printvar "START_MDADM"    "Use yes or no"
    echo
    # -----------------------------------------------------------------------
    printgroup -b 0 "Global settings"
    # -----------------------------------------------------------------------

    printvar "MDADM_DELAY"                 "Polling time, default = 60 sec"
    printvar "MDADM_MAIL"                  "Use: mailaddress from admin"
    printvar "MDADM_SEND_MAIL_ON_START"    "Send email on start yes/no"
    printvar "MDADM_SEND_EVENT_TO_SYSLOG"  "Send event messages to syslog yes/no"
    printvar "MDADM_SEND_EVENT_MAIL"       "Send event messages as mail yes/no"
    printvar "MDADM_SEND_STATUS_MAIL"      "Send status messages with cron"

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}
# ---------------------------------------------------------------------------
# create check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2011-10-02' 'hbfl' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                  OPT_VARIABLE       VARIABLE_N          VALUE
START_MDADM                 -                  -                   YESNO

MDADM_DELAY                 START_MDADM        -                   NUMERIC
MDADM_MAIL                  START_MDADM        -                   MAILADDR
MDADM_SEND_MAIL_ON_START    START_MDADM        -                   YESNO
MDADM_SEND_EVENT_TO_SYSLOG  START_MDADM        -                   YESNO
MDADM_SEND_EVENT_MAIL       START_MDADM        -                   YESNO
MDADM_SEND_STATUS_MAIL      START_MDADM        -                   ECRONTAB
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}
}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}
  
    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
