#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/mdadm.sh
#
# Creation:     2011-10-02 hbfl
# Last Update:  $Id: mdadm.sh 41043 2016-03-20 15:17:19Z hbfl $
#
# Copyright (c) 2011-2016 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

package_name='mdadm'

# set config file
config_file="/etc/config.d/${package_name}"
. ${config_file}

exec_script=/var/install/config.d/mdadm.sh
mdadm_event_handler=/sbin/mdadm-event-handler.sh
VERSION=2.6.0

#---------------------------------------------------------------------------
# start
#---------------------------------------------------------------------------
mdadm_start()
{
    cd /etc/rc2.d
    ln -sf ../init.d/${package_name} S80${package_name}
}
#---------------------------------------------------------------------------
# stop
#---------------------------------------------------------------------------
mdadm_stop()
{
    rm -f /etc/rc2.d/S??${package_name}
}
# ---------------------------------------------------------------------------
# create mdadm.conf
# ---------------------------------------------------------------------------
create_conf_file ()
{
    /var/install/bin/setup-system-filesystems-mdadm-create-conf
}

# ---------------------------------------------------------------------------
# push info
# ---------------------------------------------------------------------------
push_info()
{
    md_mail="${MDADM_MAIL}"

    if [ "${MDADM_SEND_EVENT_TO_SYSLOG}" = "yes" ]
    then
        md_syslog="true"
    fi

    if [ "${MDADM_SEND_EVENT_MAIL}" = "yes" ]
    then
        md_send="true"
    fi

    sed -i "s/^MAILADDR=.*$/MAILADDR='${md_mail}'/;
            s/^MAILSEND=.*$/MAILSEND='${md_send:-false}'/;
            s/^SYSLOG=.*$/SYSLOG='${md_syslog:-false}'/" \
            /sbin/mdadm-event-handler.sh
}

# ---------------------------------------------------------------------------
# check sendmail
# ---------------------------------------------------------------------------
check_sendmail()
{
    if [ "${MDADM_SEND_EVENT_MAIL}" = "yes" \
      -o "${MDADM_SEND_MAIL_ON_START}" = "yes" ]
    then
        if [ ! -f '/usr/sbin/sendmail' ]
        then
            set_parameter_no ${MDADM_SEND_EVENT_MAIL}
            set_parameter_no ${MDADM_SEND_MAIL_ON_START}

            echo
            mecho --error "'smtp' service not found,"
            mecho --error "the event mail can not be send."
            mecho --info  "Please install a 'smtp' service first."
            echo
            anykey
        fi
    fi
}

# ---------------------------------------------------------------------------
# set parameter to no
# ---------------------------------------------------------------------------
set_parameter_no()
{
    # set parameter from 'yes' to 'no'
    sed -i "s/^${1}=.*/${1}='no'/" ${config_file}

    echo "${1}='no'" >/tmp/eis-conf.$$
    . /tmp/eis-conf.$$
    rm -f /tmp/eis-conf.$$
}

# ---------------------------------------------------------------------------
# create crontab
# ---------------------------------------------------------------------------
create_crontab()
{
    if [ -n "${MDADM_SEND_STATUS_MAIL}" ]
    then
        # create cron job
        cat >/var/cron/etc/root/mdadm <<EOF
#----------------------------------------------------------------------------
#  cron mdadm file generated by ${package_name} version: ${VERSION}
#
#  Do not edit this file, edit ${config_file}
#  Creation Date: ${EISDATE} Time: ${EISTIME}
#----------------------------------------------------------------------------
${MDADM_SEND_STATUS_MAIL} ${exec_script} make-status
EOF

        # update crontab file
        /var/install/config.d/cron >/dev/null 2>&1
    else
        # when no, delete the cron job
        rm -rf /var/cron/etc/root/mdadm

        # update crontab file
        /var/install/config.d/cron >/dev/null 2>&1
    fi
}

# ---------------------------------------------------------------------------
# do status
# ---------------------------------------------------------------------------
do_status()
{
    ${mdadm_event_handler} "Status message"

}

# ---------------------------------------------------------------------------
# remove crontab
# ---------------------------------------------------------------------------
remove_crontab()
{
    # when no, delete the cron job
    rm -rf /var/cron/etc/root/mdadm

    # update crontab file
    /var/install/config.d/cron >/dev/null 2>&1
}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

    case ${1} in
    make-status)
        do_status
        ;;
    *)
        case ${START_MDADM} in
        yes)
            mdadm_start

            create_conf_file
            check_sendmail
            push_info
            create_crontab
            ;;
        no)
            mdadm_stop
            remove_crontab
            ;;
        esac
        ;;
    esac

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
